@@ -2,19 +2,17 @@
 #include <optional>
 #include <pybind11/operators.h>
 #include <pybind11/stl.h>
+#include <unicode/basictz.h>
 #include <unicode/calendar.h>
 #include <unicode/curramt.h>
 #include <unicode/dtintrv.h>
 #include <unicode/fmtable.h>
-#include <unicode/timezone.h>
 #include <unicode/tmutamt.h>
 
 using namespace icu;
 
-void init_fmtable(py::module &m) {
+void init_fmtable(py::module &m, py::class_<Formattable, UObject> &fmt) {
   // icu::Formattable
-  py::class_<Formattable, UObject> fmt(m, "Formattable");
-
   py::enum_<Formattable::ISDATE>(fmt, "ISDATE", py::arithmetic())
       .value("IS_DATE", Formattable::ISDATE::kIsDate)
       .export_values();
@@ -52,9 +50,19 @@ void init_fmtable(py::module &m) {
            }),
            py::arg("array_to_copy"), py::arg("count") = std::nullopt)
       // FIXME: Implement "icu::Formattable::Formattable(UObject *objectToAdopt)".
-      /*
-      .def(py::init<UObject *>(), py::keep_alive<2, 1>(), py::keep_alive<1, 2>(), py::arg("object_to_adopt"))
-      */
+      .def(py::init(
+               [](const Calendar &object_to_adopt) { return std::make_unique<Formattable>(object_to_adopt.clone()); }),
+           py::arg("object_to_adopt"))
+      .def(py::init([](const DateInterval &object_to_adopt) {
+             return std::make_unique<Formattable>(object_to_adopt.clone());
+           }),
+           py::arg("object_to_adopt"))
+      .def(py::init(
+               [](const Measure &object_to_adopt) { return std::make_unique<Formattable>(object_to_adopt.clone()); }),
+           py::arg("object_to_adopt"))
+      .def(py::init(
+               [](const TimeZone &object_to_adopt) { return std::make_unique<Formattable>(object_to_adopt.clone()); }),
+           py::arg("object_to_adopt"))
       .def(py::self != py::self, py::arg("other"))
       .def(py::self == py::self, py::arg("other"));
   fmt.def("__copy__", &Formattable::clone)
@@ -139,8 +147,9 @@ void init_fmtable(py::module &m) {
   });
   fmt.def(
       "get_object",
-      [](const Formattable &self) -> std::variant<const Calendar *, const CurrencyAmount *, const DateInterval *,
-                                                  const TimeUnitAmount *, const TimeZone *, const UObject *> {
+      [](const Formattable &self)
+          -> std::variant<const BasicTimeZone *, const Calendar *, const CurrencyAmount *, const DateInterval *,
+                          const TimeUnitAmount *, const TimeZone *, const UObject *> {
         auto obj = self.getObject();
         if (obj) {
           auto cal = dynamic_cast<const Calendar *>(obj);
@@ -159,6 +168,10 @@ void init_fmtable(py::module &m) {
           if (tuamt) {
             return tuamt;
           }
+          auto btz = dynamic_cast<const BasicTimeZone *>(obj);
+          if (btz) {
+            return btz;
+          }
           auto tz = dynamic_cast<const TimeZone *>(obj);
           if (tz) {
             return tz;
