@@ -7,15 +7,15 @@
 using namespace icu;
 
 void init_sortkey(py::module &m) {
-  py::class_<CollationKey> ck(m, "CollationKey");
+  py::class_<CollationKey, UObject> ck(m, "CollationKey");
   ck.def(py::init<>())
       .def(py::init([](const std::vector<uint8_t> &values, int32_t count) {
              return std::make_unique<CollationKey>(values.data(), count);
            }),
            py::arg("values"), py::arg("count"))
       .def(py::init<CollationKey &>(), py::arg("other"))
-      .def(py::self != py::self)
-      .def(py::self == py::self);
+      .def(py::self != py::self, py::arg("other"))
+      .def(py::self == py::self, py::arg("other"));
   ck.def(
       "compare_to",
       [](const CollationKey &self, const CollationKey &target) {
