@@ -165,6 +165,18 @@ void init_stsearch(py::module &m) {
                 return result;
               }),
           py::arg("pattern"), py::arg("text"), py::arg("locale"), py::arg("breakiter"))
+      .def(
+          // const char16_t *text -> const UnicodeString &text
+          py::init(
+              [](const UnicodeString &pattern, const char16_t *text, const Locale &locale, BreakIterator *breakiter) {
+                UErrorCode error_code = U_ZERO_ERROR;
+                auto result = std::make_unique<StringSearch>(pattern, text, locale, breakiter, error_code);
+                if (U_FAILURE(error_code)) {
+                  throw ICUException(error_code);
+                }
+                return result;
+              }),
+          py::arg("pattern"), py::arg("text"), py::arg("locale"), py::arg("breakiter"))
       .def(
           // const char *locale -> const Locale &locale
           py::init([](const UnicodeString &pattern, const UnicodeString &text, const char *locale,
@@ -177,6 +189,18 @@ void init_stsearch(py::module &m) {
             return result;
           }),
           py::arg("pattern"), py::arg("text"), py::arg("locale"), py::arg("breakiter"))
+      .def(
+          // const char16_t *pattern -> const UnicodeString &pattern
+          // const char16_t *text -> const UnicodeString &text
+          py::init([](const char16_t *pattern, const char16_t *text, const Locale &locale, BreakIterator *breakiter) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto result = std::make_unique<StringSearch>(pattern, text, locale, breakiter, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          }),
+          py::arg("pattern"), py::arg("text"), py::arg("locale"), py::arg("breakiter"))
       .def(
           // const char16_t *pattern -> const UnicodeString &pattern
           // const char *locale -> const Locale &locale
@@ -190,6 +214,32 @@ void init_stsearch(py::module &m) {
                 return result;
               }),
           py::arg("pattern"), py::arg("text"), py::arg("locale"), py::arg("breakiter"))
+      .def(
+          // const char16_t *text -> const UnicodeString &text
+          // const char *locale -> const Locale &locale
+          py::init(
+              [](const UnicodeString &pattern, const char16_t *text, const char *locale, BreakIterator *breakiter) {
+                UErrorCode error_code = U_ZERO_ERROR;
+                auto result = std::make_unique<StringSearch>(pattern, text, locale, breakiter, error_code);
+                if (U_FAILURE(error_code)) {
+                  throw ICUException(error_code);
+                }
+                return result;
+              }),
+          py::arg("pattern"), py::arg("text"), py::arg("locale"), py::arg("breakiter"))
+      .def(
+          // const char16_t *pattern -> const UnicodeString &pattern
+          // const char16_t *text -> const UnicodeString &text
+          // const char *locale -> const Locale &locale
+          py::init([](const char16_t *pattern, const char16_t *text, const char *locale, BreakIterator *breakiter) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto result = std::make_unique<StringSearch>(pattern, text, locale, breakiter, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          }),
+          py::arg("pattern"), py::arg("text"), py::arg("locale"), py::arg("breakiter"))
       .def(
           // [2] StringSearch::StringSearch
           py::init([](const UnicodeString &pattern, const UnicodeString &text, RuleBasedCollator *coll,
@@ -214,6 +264,31 @@ void init_stsearch(py::module &m) {
             return result;
           }),
           py::arg("pattern"), py::arg("text"), py::arg("coll"), py::arg("breakiter"))
+      .def(
+          // const char16_t *text -> const UnicodeString &text
+          py::init([](const UnicodeString &pattern, const char16_t *text, RuleBasedCollator *coll,
+                      BreakIterator *breakiter) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto result = std::make_unique<StringSearch>(pattern, text, coll, breakiter, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          }),
+          py::arg("pattern"), py::arg("text"), py::arg("coll"), py::arg("breakiter"))
+      .def(
+          // const char16_t *pattern -> const UnicodeString &pattern
+          // const char16_t *text -> const UnicodeString &text
+          py::init(
+              [](const char16_t *pattern, const char16_t *text, RuleBasedCollator *coll, BreakIterator *breakiter) {
+                UErrorCode error_code = U_ZERO_ERROR;
+                auto result = std::make_unique<StringSearch>(pattern, text, coll, breakiter, error_code);
+                if (U_FAILURE(error_code)) {
+                  throw ICUException(error_code);
+                }
+                return result;
+              }),
+          py::arg("pattern"), py::arg("text"), py::arg("coll"), py::arg("breakiter"))
       .def(
           // [3] StringSearch::StringSearch
           py::init([](const UnicodeString &pattern, CharacterIterator &text, const Locale &locale,
@@ -359,6 +434,17 @@ void init_stsearch(py::module &m) {
               throw ICUException(error_code);
             }
           },
+          py::arg("text"))
+      .def(
+          // const char16_t *text -> const UnicodeString &text
+          "set_text",
+          [](StringSearch &self, const char16_t *text) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            self.setText(text, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+          },
           py::arg("text"));
 
   si.def_property_readonly_static("DONE", [](py::object) -> int32_t { return USEARCH_DONE; });
