@@ -47,6 +47,17 @@ void init_uniset(py::module &m) {
              return result;
            }),
            py::arg("pattern"))
+      .def(
+          // const char16_t *pattern -> const UnicodeString &pattern
+          py::init([](const char16_t *pattern) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto result = std::make_unique<UnicodeSet>(pattern, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          }),
+          py::arg("pattern"))
       .def(py::init([](const UnicodeString &pattern, ParsePosition &pos, uint32_t options,
                        std::optional<const SymbolTable *> symbols) {
              UErrorCode error_code = U_ZERO_ERROR;
@@ -57,6 +68,18 @@ void init_uniset(py::module &m) {
              return result;
            }),
            py::arg("pattern"), py::arg("pos"), py::arg("options"), py::arg("symbols"))
+      .def(
+          // const char16_t *pattern -> const UnicodeString &pattern
+          py::init([](const char16_t *pattern, ParsePosition &pos, uint32_t options,
+                      std::optional<const SymbolTable *> symbols) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto result = std::make_unique<UnicodeSet>(pattern, pos, options, symbols.value_or(nullptr), error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          }),
+          py::arg("pattern"), py::arg("pos"), py::arg("options"), py::arg("symbols"))
       .def(py::init<const UnicodeSet &>(), py::arg("o"))
       .def(py::self != py::self, py::arg("other"))
       .def(py::self == py::self, py::arg("other"));
@@ -64,7 +87,8 @@ void init_uniset(py::module &m) {
         "__contains__", [](const UnicodeSet &self, const UnicodeString &item) { return self.contains(item); },
         py::arg("item"))
       .def(
-          "__contains__", [](const UnicodeSet &self, char16_t *item) { return self.contains(item); }, py::arg("item"))
+          "__contains__", [](const UnicodeSet &self, const char16_t *item) { return self.contains(item); },
+          py::arg("item"))
       .def(
           "__contains__", [](const UnicodeSet &self, UChar32 item) { return self.contains(item); }, py::arg("item"))
       .def("__copy__", &UnicodeSet::clone)
@@ -148,6 +172,19 @@ void init_uniset(py::module &m) {
           return result;
         },
         py::arg("pattern"), py::arg("pos"), py::arg("options"), py::arg("symbols"))
+      .def(
+          // const char16_t *pattern -> const UnicodeString &pattern
+          "apply_pattern",
+          [](UnicodeSet &self, const char16_t *pattern, ParsePosition &pos, uint32_t options,
+             std::optional<const SymbolTable *> symbols) -> UnicodeSet & {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto &result = self.applyPattern(pattern, pos, options, symbols.value_or(nullptr), error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          },
+          py::arg("pattern"), py::arg("pos"), py::arg("options"), py::arg("symbols"))
       .def(
           "apply_pattern",
           [](UnicodeSet &self, const UnicodeString &pattern) -> UnicodeSet & {
@@ -158,6 +195,18 @@ void init_uniset(py::module &m) {
             }
             return result;
           },
+          py::arg("pattern"))
+      .def(
+          // const char16_t *pattern -> const UnicodeString &pattern
+          "apply_pattern",
+          [](UnicodeSet &self, const char16_t *pattern) -> UnicodeSet & {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto &result = self.applyPattern(pattern, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          },
           py::arg("pattern"));
   us.def(
         "apply_property_alias",
@@ -214,11 +263,19 @@ void init_uniset(py::module &m) {
   us.def("close_over", &UnicodeSet::closeOver, py::arg("attribute"));
   us.def("compact", &UnicodeSet::compact);
   us.def("complement", py::overload_cast<const UnicodeString &>(&UnicodeSet::complement), py::arg("s"))
+      .def(
+          // const char16_t *s -> const UnicodeString &s
+          "complement", [](UnicodeSet &self, const char16_t *s) -> UnicodeSet & { return self.complement(s); },
+          py::arg("s"))
       .def("complement", py::overload_cast<UChar32>(&UnicodeSet::complement), py::arg("c"))
       .def("complement", py::overload_cast<UChar32, UChar32>(&UnicodeSet::complement), py::arg("start"), py::arg("end"))
       .def("complement", py::overload_cast<>(&UnicodeSet::complement));
   us.def("complement_all", py::overload_cast<const UnicodeSet &>(&UnicodeSet::complementAll), py::arg("c"))
-      .def("complement_all", py::overload_cast<const UnicodeString &>(&UnicodeSet::complementAll), py::arg("s"));
+      .def("complement_all", py::overload_cast<const UnicodeString &>(&UnicodeSet::complementAll), py::arg("s"))
+      .def(
+          // const char16_t *s -> const UnicodeString &s
+          "complement_all", [](UnicodeSet &self, const char16_t *s) -> UnicodeSet & { return self.complementAll(s); },
+          py::arg("s"));
   us.def("contains", py::overload_cast<const UnicodeString &>(&UnicodeSet::contains, py::const_), py::arg("s"))
       .def(
           // const char16_t *s -> const UnicodeString &s
@@ -280,7 +337,7 @@ void init_uniset(py::module &m) {
   us.def("remove", py::overload_cast<const UnicodeString &>(&UnicodeSet::remove), py::arg("s"))
       .def(
           // const char16_t *s -> const UnicodeString &s
-          "remove", [](UnicodeSet &self, const char16_t *s) -> UnicodeSet & { return self.remove(s); })
+          "remove", [](UnicodeSet &self, const char16_t *s) -> UnicodeSet & { return self.remove(s); }, py::arg("s"))
       .def("remove", py::overload_cast<UChar32>(&UnicodeSet::remove), py::arg("c"))
       .def("remove", py::overload_cast<UChar32, UChar32>(&UnicodeSet::remove), py::arg("start"), py::arg("end"));
   us.def("remove_all", py::overload_cast<const UnicodeSet &>(&UnicodeSet::removeAll), py::arg("c"))
@@ -296,6 +353,11 @@ void init_uniset(py::module &m) {
           "resembles_pattern",
           [](const char16_t *pattern, int32_t pos) { return UnicodeSet::resemblesPattern(pattern, pos); },
           py::arg("pattern"), py::arg("pos"));
+#if (U_ICU_VERSION_MAJOR_NUM >= 69)
+  us.def("retain", py::overload_cast<const UnicodeString &>(&UnicodeSet::retain), py::arg("s"))
+      .def(
+          "retain", [](UnicodeSet &self, const char16_t *s) -> UnicodeSet & { return self.retain(s); }, py::arg("s"));
+#endif // (U_ICU_VERSION_MAJOR_NUM >= 69)
   us.def("retain", py::overload_cast<UChar32>(&UnicodeSet::retain), py::arg("c"))
       .def("retain", py::overload_cast<UChar32, UChar32>(&UnicodeSet::retain), py::arg("start"), py::arg("end"));
   us.def("retain_all", py::overload_cast<const UnicodeSet &>(&UnicodeSet::retainAll), py::arg("c"))
