@@ -669,8 +669,18 @@ void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class
       .def("last_index_of", py::overload_cast<UChar32, int32_t, int32_t>(&UnicodeString::lastIndexOf, py::const_),
            py::arg("c"), py::arg("start"), py::arg("length"));
   us.def("move_index32", &UnicodeString::moveIndex32, py::arg("index"), py::arg("delta"));
-  us.def("pad_leading", &UnicodeString::padLeading, py::arg("target_length"), py::arg("pad_char") = "\x20");
-  us.def("pad_trailing", &UnicodeString::padTrailing, py::arg("target_length"), py::arg("pad_char") = "\x20");
+  us.def(
+      "pad_leading",
+      [](UnicodeString &self, int32_t target_length, uint16_t pad_char) {
+        return self.padLeading(target_length, pad_char);
+      },
+      py::arg("target_length"), py::arg("pad_char") = 0x20);
+  us.def(
+      "pad_trailing",
+      [](UnicodeString &self, int32_t target_length, uint16_t pad_char) {
+        return self.padTrailing(target_length, pad_char);
+      },
+      py::arg("target_length"), py::arg("pad_char") = 0x20);
   us.def("remove", py::overload_cast<>(&UnicodeString::remove))
       .def("remove", py::overload_cast<int32_t, int32_t>(&UnicodeString::remove), py::arg("start"),
            py::arg("length") = (int32_t)INT32_MAX)
@@ -750,7 +760,8 @@ void init_unistr(py::module &m, py::class_<Replaceable, UObject> &rep, py::class
           "set_to",
           [](UnicodeString &self, UBool is_terminated, const char16_t *text, int32_t text_length) -> UnicodeString & {
             return self.setTo(is_terminated, text, text_length);
-          })
+          },
+          py::arg("is_terminated"), py::arg("text"), py::arg("text_length"))
       .def("set_to", py::overload_cast<UChar32>(&UnicodeString::setTo), py::arg("src_char"));
   us.def("set_to_bogus", &UnicodeString::setToBogus);
   us.def("starts_with", py::overload_cast<const char16_t *, int32_t, int32_t>(&UnicodeString::startsWith, py::const_),
