@@ -14,8 +14,6 @@ public:
   // template <typename T> _ConstVoidPtr(T value);
   ~_ConstVoidPtr();
 
-  std::any &get() { return context_; }
-
   py::function &get_action() { return action_; }
 
   bool has_value() const { return context_.has_value(); }
@@ -26,8 +24,6 @@ public:
 
   py::object to_object() const;
 
-  template <typename T> auto value() const { return std::any_cast<T>(context_); }
-
 private:
   _ConstVoidPtr() = delete;
   std::any context_;
